/****************************************************************************
** Meta object code from reading C++ file 'qvideoframe.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtmultimedia/src/multimedia/video/qvideoframe.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qvideoframe.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11QVideoFrameE_t {};
} // unnamed namespace

template <> constexpr inline auto QVideoFrame::qt_create_metaobjectdata<qt_meta_tag_ZN11QVideoFrameE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QVideoFrame",
        "MapMode",
        "NotMapped",
        "ReadOnly",
        "WriteOnly",
        "ReadWrite"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'MapMode'
        QtMocHelpers::EnumData<enum MapMode>(1, 1, QMC::EnumFlags{}).add({
            {    2, MapMode::NotMapped },
            {    3, MapMode::ReadOnly },
            {    4, MapMode::WriteOnly },
            {    5, MapMode::ReadWrite },
        }),
    };
    return QtMocHelpers::metaObjectData<QVideoFrame, qt_meta_tag_ZN11QVideoFrameE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QVideoFrame::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11QVideoFrameE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11QVideoFrameE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11QVideoFrameE_t>.metaTypes,
    nullptr
} };

QT_WARNING_POP
