/****************************************************************************
** Meta object code from reading C++ file 'qmediadevices.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtmultimedia/src/multimedia/qmediadevices.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qmediadevices.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13QMediaDevicesE_t {};
} // unnamed namespace

template <> constexpr inline auto QMediaDevices::qt_create_metaobjectdata<qt_meta_tag_ZN13QMediaDevicesE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QMediaDevices",
        "audioInputsChanged",
        "",
        "audioOutputsChanged",
        "videoInputsChanged",
        "audioInputs",
        "QList<QAudioDevice>",
        "audioOutputs",
        "videoInputs",
        "QList<QCameraDevice>",
        "defaultAudioInput",
        "QAudioDevice",
        "defaultAudioOutput",
        "defaultVideoInput",
        "QCameraDevice"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'audioInputsChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'audioOutputsChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'videoInputsChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'audioInputs'
        QtMocHelpers::PropertyData<QList<QAudioDevice>>(5, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'audioOutputs'
        QtMocHelpers::PropertyData<QList<QAudioDevice>>(7, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'videoInputs'
        QtMocHelpers::PropertyData<QList<QCameraDevice>>(8, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 2),
        // property 'defaultAudioInput'
        QtMocHelpers::PropertyData<QAudioDevice>(10, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'defaultAudioOutput'
        QtMocHelpers::PropertyData<QAudioDevice>(12, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'defaultVideoInput'
        QtMocHelpers::PropertyData<QCameraDevice>(13, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 2),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QMediaDevices, qt_meta_tag_ZN13QMediaDevicesE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QMediaDevices::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13QMediaDevicesE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13QMediaDevicesE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13QMediaDevicesE_t>.metaTypes,
    nullptr
} };

void QMediaDevices::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QMediaDevices *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->audioInputsChanged(); break;
        case 1: _t->audioOutputsChanged(); break;
        case 2: _t->videoInputsChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QMediaDevices::*)()>(_a, &QMediaDevices::audioInputsChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QMediaDevices::*)()>(_a, &QMediaDevices::audioOutputsChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QMediaDevices::*)()>(_a, &QMediaDevices::videoInputsChanged, 2))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QList<QAudioDevice>*>(_v) = _t->audioInputs(); break;
        case 1: *reinterpret_cast<QList<QAudioDevice>*>(_v) = _t->audioOutputs(); break;
        case 2: *reinterpret_cast<QList<QCameraDevice>*>(_v) = _t->videoInputs(); break;
        case 3: *reinterpret_cast<QAudioDevice*>(_v) = _t->defaultAudioInput(); break;
        case 4: *reinterpret_cast<QAudioDevice*>(_v) = _t->defaultAudioOutput(); break;
        case 5: *reinterpret_cast<QCameraDevice*>(_v) = _t->defaultVideoInput(); break;
        default: break;
        }
    }
}

const QMetaObject *QMediaDevices::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QMediaDevices::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13QMediaDevicesE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int QMediaDevices::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 3;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void QMediaDevices::audioInputsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QMediaDevices::audioOutputsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QMediaDevices::videoInputsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
